pub struct AppHubApplication {
pub container: Option<String>,
pub id: Option<String>,
pub location: Option<String>,
}Expand description
Resource identifiers associated with an AppHub application AppHub resources are of the form projects//locations//applications/ projects//locations//applications//services/ projects//locations//applications//workloads/ These resources can be reconstructed from the components below.
This type is not used in any activity, and only used as part of another schema.
Fields
container: Option<String>Resource container that owns the application. Example: “projects/management_project”
id: Option<String>Application Id. Example: “my-app”
location: Option<String>Location associated with the Application. Example: “us-east1”