Struct google_logging2::LabelDescriptor [−][src]
pub struct LabelDescriptor {
pub value_type: Option<String>,
pub description: Option<String>,
pub key: Option<String>,
}A description of a label.
This type is not used in any activity, and only used as part of another schema.
Fields
value_type: Option<String>
The type of data that can be assigned to the label.
description: Option<String>
A human-readable description for the label.
key: Option<String>
The label key.